Django-ndator
-----

Data obfuscation for django

    Usage: ./manage.py nda [options] [nda models]

    --allauto             Try to make obfuscation with defaultsettings
    --noinput             Do NOT ask any questions before obfuscation

    [nda models] — specify NdaModel classes names, which will be obfuscated
